# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 06:25:01 2018 from module list in Acme::CPANLists::PERLANCAR::Temp::Plus version 0.002.

package Acme::CPANModules::PERLANCAR::Temp::Plus;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  entries => [
               { date => "2016-12-15", module => "App::Trrr" },
               { date => "2016-12-21", module => "App::Wax" },
               { date => "2016-12-25", module => "App::cpangrep" },
               { date => "2017-02-04", module => "Acme::PPIx::MetaSyntactic" },
             ],
  summary => "Modules I plus while MetaCPAN's ++ is not working",
};

1;
# ABSTRACT: Modules I plus while MetaCPAN's ++ is not working

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::PERLANCAR::Temp::Plus - Modules I plus while MetaCPAN's ++ is not working

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::PERLANCAR::Temp::Plus (from Perl distribution Acme-CPANModules-PERLANCAR-Temp-Plus), released on 2018-09-22.

=head1 DESCRIPTION

Modules I plus while MetaCPAN's ++ is not working.

=head1 INCLUDED MODULES

=over

=item * L<App::Trrr>

=item * L<App::Wax>

=item * L<App::cpangrep>

=item * L<Acme::PPIx::MetaSyntactic>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModules-PERLANCAR-Temp-Plus>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-PERLANCAR-Temp-Plus>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-PERLANCAR-Temp-Plus>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
